Types
=====

Lifetime
--------

.. autoclass:: diwire.Lifetime
   :members:

Scope
-----

.. autoclass:: diwire.Scope
   :members:

Injected
--------

.. autoclass:: diwire.Injected

Component
---------

.. autoclass:: diwire.Component
